::: {.callout-important appearance="default" icon="true"}
Sprout assumes you have control over your system's files and folders, or
at least your user's home directory. This includes having access to a
server through the Terminal where you can write to specific folders.
:::
